Credits
=======

Development Lead
----------------

* Jan Bessai <jan.bessai@tu-dortmund.de>


Contributors
------------

* Anne Meyer <anne2.meyer@tu-dortmund.de>
* Hadi Kutabi <hadi.kutabi@tu-dortmund.de>
* Daniel Scholtyssek <daniel.scholtyssek@tu-dortmund.de>


Software Libraries
------------------

This project includes the following software libraries:

.. raw:: html

        <p><details>
        <summary>d3.js</summary>
        <br>
        <hr style="border: none; border-top: 1px solid black; margin: 0; width: 100%;">
        This project includes d3.js developed by Mike Bostock. D3.js is licensed under the ISC License.<br><br>

        Copyright 2010-2019 Mike Bostock<br><br>

        D3.js is distributed under the terms of the ISC License. You can find the full text of the license in the <a href="https://github.com/cls-python/cls-luigi/blob/main/LICENCES/D3_LICENSE">D3_LICENSE</a> file.<br><br>

        For more information about D3.js, please visit the
        <a href="https://d3js.org/">official website</a> or refer to the <a href="https://github.com/d3/d3">GitHub repository</a>.
        <hr style="border: none; border-top: 1px solid black; margin: 0; width: 100%;">
        </details>
        </p>

        <p><details>
        <summary>dagre-d3.js</summary>
        <br>
        <hr style="border: none; border-top: 1px solid black; margin: 0; width: 100%;">
        This project includes dagre-d3.js developed by Chris Pettitt. dagre-d3.js is licensed under the MIT License.<br><br>

        Copyright 2013 Chris Pettitt<br><br>

        dagre-d3.js is distributed under the terms of the MIT License. You can find the full text of the license in the <a href="https://github.com/cls-python/cls-luigi/blob/main/LICENCES/DAGRE-D3_LICENSE">DAGRE-D3_LICENSE</a> file.<br><br>

        For more information about dagre-d3.js, please visit the <a href="https://github.com/dagrejs/dagre-d3">GitHub repository</a>.
        <hr style="border: none; border-top: 1px solid black; margin: 0; width: 100%;">
        </details>
        </p>
